==> mule-transport-file-1.3-rc5-sources.jar: org/mule/providers/file/FileContentsMessageAdapter.java <==
/*
 * $Id: FileContentsMessageAdapter.java 3167 2006-09-22 15:47:04 +0000 (Fri, 22 Sep 2006) holger $
 * --------------------------------------------------------------------------------------
 * Copyright (c) MuleSource, Inc.  All rights reserved.  http://www.mulesource.com
 *
 * The software in this package is published under the terms of the MuleSource MPL
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */

package org.mule.providers.file;

import org.mule.MuleRuntimeException;
import org.mule.config.i18n.Message;
import org.mule.config.i18n.Messages;
import org.mule.umo.MessagingException;

import java.io.File;

/**
 * <code>FileContentsMessageAdapter</code> provides a wrapper for file data.
 * Users can obtain the contents of the message through the payload property and
 * can get the filename and directory in the properties using PROPERTY_FILENAME
 * and PROPERTY_DIRECTORY.
 * 
 * @author <a href="mailto:ross.mason@symphonysoft.com">Ross Mason</a>
 * @version $Revision: 3167 $
 */
public class FileContentsMessageAdapter extends FileMessageAdapter
{
    /**
     * Serial version
     */
    private static final long serialVersionUID = 7368719494535568721L;

    public FileContentsMessageAdapter(Object message) throws MessagingException
    {
        super(message);
    }

    protected void setMessage(File message) throws MessagingException
    {
        super.setMessage(message);
        // force reading of file (lazy loading would be really, really
        // complicated)
        this.getPayload();
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.mule.providers.UMOMessageAdapter#getPayload()
     */
    public Object getPayload()
    {
        synchronized (this)
        {
            try
            {
                return this.getPayloadAsBytes();
            } catch (Exception noPayloadException)
            {
                throw new MuleRuntimeException(new Message(
                        Messages.FAILED_TO_READ_PAYLOAD), noPayloadException);
            }
        }
    }

}

==> mule-transport-file-1.3.2-sources.jar: org/mule/providers/file/FileContentsMessageAdapter.java <==
/*
 * $Id: FileContentsMessageAdapter.java 3798 2006-11-04 04:07:14Z aperepel $
 * --------------------------------------------------------------------------------------
 * Copyright (c) MuleSource, Inc.  All rights reserved.  http://www.mulesource.com
 *
 * The software in this package is published under the terms of the MuleSource MPL
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */

package org.mule.providers.file;

import java.io.File;

import org.mule.MuleRuntimeException;
import org.mule.config.i18n.Message;
import org.mule.config.i18n.Messages;
import org.mule.umo.MessagingException;

/**
 * <code>FileContentsMessageAdapter</code> provides a wrapper for file data. Users
 * can obtain the contents of the message through the payload property and can get
 * the filename and directory in the properties using PROPERTY_FILENAME and
 * PROPERTY_DIRECTORY.
 */
public class FileContentsMessageAdapter extends FileMessageAdapter
{
    /**
     * Serial version
     */
    private static final long serialVersionUID = 7368719494535568721L;

    public FileContentsMessageAdapter(Object message) throws MessagingException
    {
        super(message);
    }

    protected void setMessage(File message) throws MessagingException
    {
        super.setMessage(message);
        // force reading of file (lazy loading would be really, really complicated)
        this.getPayload();
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.mule.providers.UMOMessageAdapter#getPayload()
     */
    public Object getPayload()
    {
        synchronized (this)
        {
            try
            {
                return this.getPayloadAsBytes();
            }
            catch (Exception noPayloadException)
            {
                throw new MuleRuntimeException(new Message(Messages.FAILED_TO_READ_PAYLOAD),
                    noPayloadException);
            }
        }
    }

}
